<!-- warning: Please don't edit this file. It was automatically generated. -->

# winrt-Windows.Storage.Streams

Windows Runtime (WinRT) APIs for for the `Windows.Storage.Streams` namespace.

This package provides the `winrt.windows.storage.streams` module.
